@@ -390,6 +390,27 @@ _g_str_get_static (const char *s)
 }
 
 
+/* utf8 */
+
+
+gboolean
+_g_utf8_all_spaces (const char *text)
+{
+	const char *scan;
+
+	if (text == NULL)
+		return TRUE;
+
+	for (scan = text; *scan != 0; scan = g_utf8_next_char (scan)) {
+		gunichar c = g_utf8_get_char (scan);
+		if (! g_unichar_isspace (c))
+			return FALSE;
+	}
+
+	return TRUE;
+}
+
+
 /* string vector */
 
 
